@@ -2,7 +2,12 @@ from ..nba.constants import *
 from enum import Enum
 from inspect import isclass
 
-import os
+try:
+    import importlib.resources as pkg_resources
+except ImportError:
+    # Try backported to PY<37 `importlib_resources`.
+    import importlib_resources as pkg_resources
+
 import requests
 import requests_cache
 import logging
@@ -48,12 +53,23 @@ def clean_inputs(func):
 
 class StatsNbaApi:
     def __init__(self):
-        with open(f'./specs/stats.nba.com.json', 'r') as f:
-            self.specs = json.load(f)
+        logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(levelname)s: %(message)s')
+        self.logger = logging.getLogger('sportsdata')
 
-        self.endpoints = {}
-        for endpoint in self.specs['stats_endpoints']:
-            self.endpoints[endpoint['name']] = endpoint
+        # TODO: Properly load / leverage specification file
+        api_spec_json = pkg_resources.read_text(__name__, 'data/stats.nba.com.json')
+        self.logger.info(api_spec_json)
+
+        # spec_json = pkg_resources.read_text(specs, 'stats.nba.com.json')
+        # print(spec_json)
+        # or for a file-like stream:
+        # template = pkg_resources.open_text(templates, 'temp_file')
+        # with open(f'{path.dirname(__file__)}/specs/stats.nba.com.json', 'r') as f:
+        #     self.specs = json.load(f)
+        #
+        # self.endpoints = {}
+        # for endpoint in self.specs['stats_endpoints']:
+        #     self.endpoints[endpoint['name']] = endpoint
 
     base_url = "http://stats.nba.com/stats/{0}"
     headers = {
@@ -496,44 +512,57 @@ class StatsNbaApi:
 
     @clean_inputs
     def league_game_log(self,
-                        season,
+                        counter=0,
                         direction=Direction.DESC.value,
                         league_id=League.NBA.value,
-                        player_or_team=PlayerOrTeam.TEAM.value,
-                        season_type=SeasonType.REGULAR_SEASON.value,
-                        sorter=StatCategory.FIELD_GOALS_MADE.value):
+                        player_or_team_abbreviation=PlayerOrTeam.TEAM.value,
+                        season=2021,
+                        season_type_all_star=SeasonType.REGULAR_SEASON.value,
+                        sorter=SortOrder.DATE.value,
+                        date_from_nullable='',
+                        date_to_nullable='',
+                        proxy=None,
+                        headers=None,
+                        timeout=30,
+                        ):
         """
 
-        Args:
-            season:
-            direction:
-            league_id:
-            player_or_team:
-            season_type:
-            sorter:
-
-        Returns:
-            'SEASON_ID', 'TEAM_ID', 'TEAM_ABBREVIATION', 'TEAM_NAME', 'GAME_ID', GAME_DATE',
+        :param counter:
+        :param direction:
+        :param league_id:
+        :param player_or_team_abbreviation:
+        :param season:
+        :param season_type_all_star:
+        :param sorter:
+        :param date_from_nullable:
+        :param date_to_nullable:
+        :param proxy:
+        :param headers:
+        :param timeout:
+        :return:
+                    'SEASON_ID', 'TEAM_ID', 'TEAM_ABBREVIATION', 'TEAM_NAME', 'GAME_ID', GAME_DATE',
             'MATCHUP', 'WL', 'MIN', 'FGM', 'FGA', 'FG_PCT', 'FG3M', 'FG3A', 'FG3_PCT', 'FTM',
             'FTA', 'FT_PCT', 'OREB', 'DREB', 'REB', 'AST', 'STL', 'BLK', 'TOV', 'PF', 'PTS', 'PLUS_MINUS', 'VIDEO_AVAILABLE'
-
         """
         url = self.base_url.format('leaguegamelog')
-        print(url)
-        url = self.endpoints['league_game_log']['url']
-        parameters = self.endpoints['league_game_log']['parameters']
-        print(url)
-        print(parameters)
-        return
-        params = {
-            'LeagueID': league_id,
-            'Season': season,
-            'SeasonType': season_type,
+        self.logger.info(url)
+
+        parameters = {
+            'Counter': counter,
             'Direction': direction,
-            'PlayerOrTeam': player_or_team,
-            'Sorter': sorter
+            'LeagueID': league_id,
+            'PlayerOrTeam': player_or_team_abbreviation,
+            'Season': season,
+            'SeasonType': season_type_all_star,
+            'Sorter': sorter,
+            'DateFrom': date_from_nullable,
+            'DateTo': date_to_nullable
         }
-        response = requests.get(url, headers=self.headers, params=params)
+
+        self.logger.info(parameters)
+        # response = requests.get(url, headers=self.headers, params=params, timeout=10)
+
+        response = requests.get('https://stats.nba.com/stats/leaguegamelog?Counter=0&DateFrom=&DateTo=&Direction=ASC&LeagueID=00&PlayerOrTeam=T&Season=2021&SeasonType=Regular+Season&Sorter=DATE')
         data = ResponseParser.get_data_frames(response)
         return data
 
